@@ -8,7 +8,7 @@ use base qw(Net::DNS::Resolver DynaLoader);
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.19_02';
+	$VERSION = '1.19_03';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -29,7 +29,8 @@ Net::DNS::Resolver::Unbound - Net::DNS resolver based on libunbound
 =head1 DESCRIPTION
 
 Net::DNS::Resolver::Unbound is designed as an extension to an existing
-Net::DNS installation which facilitates DNS(SEC) name resolution.
+Net::DNS installation which facilitates DNS(SEC) name resolution using
+the libunbound library developed by NLnet Labs.
 
 Net::DNS::Resolver::Unbound replaces the resolver send() and bgsend()
 functionality in the Net::DNS::Resolver::Base implementation.
@@ -94,7 +95,12 @@ sub new {
 	);
 
     my $fully_recursive = Net::DNS::Resolver::Unbound->new(
-	nameservers => [],		# override /etc/resolv.conf
+	nameservers => []		# override /etc/resolv.conf
+	);
+
+    my $dnssec_resolver = Net::DNS::Resolver::Unbound->new(
+	nameservers => [],
+	add_ta_file => '/var/lib/unbound/root.key'
 	);
 
     my @nameservers = $stub_resolver->nameservers;
@@ -422,9 +428,11 @@ sub _decode_result {
 	$self->errorstring( $result->why_bogus ) if $result->bogus;
 
 	my $buffer = $result->answer_packet || return;
-	my $packet = Net::DNS::Packet->decode( \$buffer, $self->debug );
+	my $packet = Net::DNS::Packet->decode(\$buffer);
 	$self->errorstring($@);
 	$packet->header->id($query_id) if !UB_SEND || $query_id;
+	$packet->print if $self->debug;
+
 	return $packet;
 }
 
